/* 
 * CUAG AutoUmpire System
 * 
 * Copyright (C) 2003/2004 Matthew Johnson, Adam Biltcliffe,
 * Michael Cripps, Martin O'Leary, Edward Allcutt, Jonathan Hogg 
 * and James Osborn
 *
 * This program is free software; you can redistribute it and/or 
 * modify it under the terms of the GNU General Public License 
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version. 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details. 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 * To Contact the authors, please email assassins@srcf.ucam.org
 *
 */

package org.ucam.srcf.assassins;

/**
 * Class to provide a safe and secure authentication mechanism.
 * Implemented using cookies and password.
 */
public class AuthLevel implements Comparable {
	private int value;
	private String name;
	
	private AuthLevel(int number, String name) {
		this.value=number;
		this.name=name;
	}

	public int compareTo(Object obj) {
		return this.value - ((AuthLevel) obj).value;
	}

	/* Warning! changing these values may cause db inconsistency! */
	public static final AuthLevel PUBLIC = new AuthLevel(0,"A Member of the Public");
	public static final AuthLevel LOGGED_IN = new AuthLevel(5,"Someone logged in"); /* should not be used, but require all users with logins above this rating*/
	public static final AuthLevel PLAYER = new AuthLevel(50, "A Player");
	public static final AuthLevel UMPIRE = new AuthLevel(100, "The Umpire");

/* FIXME: rewrite this using some form of sorted list? */
	public static AuthLevel getLevel(int number) {
		switch(number) {
			case 5:
				return AuthLevel.LOGGED_IN;
			case 50:
				return AuthLevel.PLAYER;
			case 100:
				return AuthLevel.UMPIRE;
			default:
				return AuthLevel.PUBLIC;
		}
	}

	public String toString() {
		return name;
	}

	public int getInt() {
		return value;
	}
}
