/* 
 * CUAG AutoUmpire System
 * 
 * Copyright (C) 2003/2004 Matthew Johnson, Adam Biltcliffe,
 * Michael Cripps, Martin O'Leary, Edward Allcutt and James Osborn
 *
 * This program is free software; you can redistribute it and/or 
 * modify it under the terms of the GNU General Public License 
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version. 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details. 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 * To Contact the authors, please email assassins@srcf.ucam.org
 *
 */

package org.ucam.srcf.assassins;

import java.io.IOException;
import java.text.ParseException;
import java.util.Map;
import java.util.Iterator;

import cx.ath.matthew.cgi.CGI;

import org.ucam.srcf.assassins.exceptions.AssassinSQLException;
import org.ucam.srcf.assassins.exceptions.StateBuilderException;

public class CGIDumpState implements CGICommand
{
   private void dumpState(CGI cgi, Map plugins, Map params) throws AssassinSQLException , StateBuilderException
   {
      cgi.out("<p>Building State, please wait...</p>");
      cgi.flush();
      StateBuilder sb = new StateBuilder(plugins);
      Map state;
      try {
         state = sb.buildStateAtTime(Tools.getNowTime());
      } catch (StateBuilderException sbe) {
         cgi.out("<div class=\"errormessage\">");
         cgi.out("  <p><b>Internal Error</b></p>");
         cgi.out("  <p>State Building failed! Very bad!!</p>");
         cgi.out("</div>");
         cgi.flush();
         throw new RuntimeException();
      }
      Iterator i = state.values().iterator();
      while (i.hasNext())
      {
         AssassinState s = (AssassinState) i.next();
         Assassin a = s.getAssassin();
         Player p = a.getPlayer();
         cgi.out("<h3>Assassin played by "+p.getName()+"</h3>");
         cgi.out("<table>");
         cgi.out("<thead>");
         cgi.out("  <tr><td colspan='3'>Properties</td></tr>");
         cgi.out("  <tr>");
         cgi.out("     <td>Plugin</td>");
         cgi.out("     <td>Field</td>");
         cgi.out("     <td>Value</td>");
         cgi.out("  </tr>");
         cgi.out("</thead>");
         cgi.out("<tbody>");
         Iterator pni = s.getKnownPlugins().iterator();
         while (pni.hasNext())
         {
            String pname = (String) pni.next();
            Map pstate = s.getState(pname);
            Iterator ki = pstate.keySet().iterator();
            while (ki.hasNext())
            {
               String field = (String) ki.next();
               Object v = s.getProperty(pname, field);
               cgi.out("  <tr>");
               cgi.out("     <td>"+pname+"</td>");
               cgi.out("     <td>"+field+"</td>");
               cgi.out("     <td>"+(null == v ? "null" : v.toString())+"</td>");
               cgi.out("  </tr>");
            }
         }
         cgi.out("</tbody>");
         cgi.out("</table>");
         cgi.out("<h4>Pseudonyms:</h4>");
         cgi.out("<ul>");
         Iterator psi = s.getPseudonyms().iterator();
         while (psi.hasNext())
         {
            Pseudonym ps = (Pseudonym) psi.next();
            cgi.out("   <li>"+ps.getValue()+"</li>");
         }
         cgi.out("</ul>");
      }
   }
   public void command(CGI cgi, Map plugins, Map params, long nowtime) 
      throws AssassinSQLException, IOException, ParseException, StateBuilderException {  dumpState(cgi, plugins, params); }
   public String getName() { return "Dump State"; }
   public String getDescription() { return "Dumps the current state values for all assassins"; }
   public AuthLevel accessLevel () { return AuthLevel.UMPIRE; }
   public String getSection() { return "Misc"; }
}

